@@ -2,7 +2,7 @@
  *
  * Interface to block cryptos and hash functions
  *
- * $Id: abstract_crypto.h,v 1.27 2000/05/01 19:09:55 nisse Exp $ */
+ * $Id: abstract_crypto.h,v 1.28 2000/05/29 19:32:45 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -209,6 +209,13 @@ hash_string(struct hash_algorithm *a,
 	    struct lsh_string *in,
 	    int free);
 
+struct lsh_string *
+mac_string(struct mac_algorithm *a,
+	   struct lsh_string *key,
+	   int kfree,
+	   struct lsh_string *in,
+	   int ifree);
+
 struct lsh_string *
 crypt_string(struct crypto_instance *c,
 	     struct lsh_string *in,
