@@ -1,6 +1,6 @@
 /* channel.c
  *
- * $Id: channel.c,v 1.80 2000/05/06 11:17:28 nisse Exp $
+ * $Id: channel.c,v 1.81 2000/05/22 20:47:34 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -432,8 +432,12 @@ adjust_rec_window(struct flow_controlled *f, UINT32 written)
 {
   CAST_SUBTYPE(ssh_channel, channel, f);
 
-  A_WRITE(channel->write,
-	  prepare_window_adjust(channel, written));
+  /* NOTE: The channel object (referenced as a flow-control callback)
+   * may live longer than the actual channel. */
+  if (! (channel->flags & (CHANNEL_RECEIVED_EOF | CHANNEL_RECEIVED_CLOSE
+			   | CHANNEL_SENT_CLOSE)))
+    A_WRITE(channel->write,
+	    prepare_window_adjust(channel, written));
 }
 
 void
