@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: read_packet.c,v 1.46 2000/02/02 22:44:00 nisse Exp $ */
+ * $Id: read_packet.c,v 1.47 2000/05/06 11:17:39 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -232,7 +232,8 @@ do_read_packet(struct read_handler **h,
 			       length - done,
 			       &closure->crypt_pos);
 
-		/* FIXME: Is this needed anywhere? */
+		/* The sequence number is needed by the handler for
+		 * unimplemented message types. */
 		closure->packet_buffer->sequence_number
 		  = closure->sequence_number++;
 
@@ -351,8 +352,6 @@ do_read_packet(struct read_handler **h,
       default:
 	fatal("Internal error\n");
     }
-  /* FIXME: Not reached. */
-  return total;
 }
 
 struct read_handler *
