@@ -2,7 +2,7 @@
  *
  * user authorization database
  *
- * $Id: server_authorization.c,v 1.10 2000/03/19 16:56:19 nisse Exp $ */
+ * $Id: server_authorization.c,v 1.11 2000/04/02 19:33:27 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -51,7 +51,7 @@
 static struct verifier *
 do_key_lookup(struct lookup_verifier *c,
 	      int method,
-	      struct user *keyholder,
+	      struct lsh_user *keyholder,
 	      struct lsh_string *key)
 {
   CAST(authorization_db, closure, c);
