@@ -2,7 +2,7 @@
  *
  * System dependant password related functions.
  *
- * $Id: server_password.c,v 1.29 2000/04/02 19:33:28 nisse Exp $
+ * $Id: server_password.c,v 1.30 2000/04/21 22:29:41 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -138,93 +138,3 @@ make_userauth_password(struct user_db *db)
   return &self->super;
 }
 
-#if 0
-
-struct userauth unix_userauth =
-{ STATIC_HEADER, do_authenticate };
-
-
-struct setuid_service
-{
-  struct ssh_service super;
-
-  struct unix_user *user;
-  /* Service to start once we have changed to the correct uid. */
-  struct ssh_service *service;
-};
-
-/* NOTE: This is used only if early forking (i.e., for directly after
- * user autentication) is enabled. */
-static int do_setuid(struct ssh_service *c,
-		     struct ssh_connection *connection)
-{
-  CAST(setuid_service, closure, c);  
-  uid_t server_uid = getuid();
-  int res = 0;
-
-  if (server_uid != closure->user->uid)
-    {
-      if (server_uid)
-	/* Not root */
-	return LSH_AUTH_FAILED;
-
-      switch(fork())
-	{
-	case -1:
-	  /* Error */
-	  werror("fork failed: %z\n", STRERROR(errno));
-	  return LSH_FAIL | LSH_DIE;
-	case 0:
-	  /* Child */
-
-	  if (!change_uid(closure->user))
-	    return  LSH_FAIL | LSH_DIE | LSH_KILL_OTHERS;;
-
-	  res |= LSH_KILL_OTHERS;
-	  break;
-	default:
-	  /* Parent */
-	  return LSH_OK | LSH_DIE;
-	}
-    }
-
-  /* Change to user's home directory. FIXME: If the server is running
-   * as the same user, perhaps it's better to use $HOME? */
-  if (!change_dir(closure->user))
-    fatal("can't chdir: giving up\n");
-
-  /* Initialize environment, somehow. In particular, the HOME and
-   * LOGNAME variables */
-
-  return res | LOGIN(closure->service, closure->user);		     connection);
-}
-
-/* FIXME: This function is not quite adequate, as it does not pass the
- * user struct on to the started service. */
-
-static struct ssh_service *do_login(struct login_method *closure,
-				    struct unix_user *user,
-				    struct ssh_service *service)
-{
-  struct setuid_service *res;
-
-  MDEBUG(closure);
-  
-  NEW(res);
-  res->super.init = do_setuid;
-  res->user = user;
-  res->service = service;
-
-  return &res->super;
-}
-
-struct login_method *make_unix_login(void)
-{
-  struct login_method *self;
-
-  NEW(self);
-  self->login = do_login;
-
-  return self;
-}
-#endif
