@@ -2,7 +2,7 @@
  *
  * Reading and writing of s-expressions.
  *
- * $Id: sexp_commands.c,v 1.11 2000/06/01 10:56:29 nisse Exp $ */
+ * $Id: sexp_commands.c,v 1.12 2000/06/21 06:38:31 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -134,7 +134,7 @@ do_print_raw_hash_to(struct command *s,
   lsh_string_free(canonical);
   KILL(hash);
 
-  A_WRITE(self->dest, ssh_format("%lxfS", digest));
+  A_WRITE(self->dest, ssh_format("%lxfS\n", digest));
 
   COMMAND_RETURN(c, a);
 }
