@@ -2,7 +2,7 @@
  *
  * SPKI interface
  *
- * $Id: spki_commands.c,v 1.6 2000/05/01 20:38:32 nisse Exp $ */
+ * $Id: spki_commands.c,v 1.8 2000/06/01 13:18:11 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -69,13 +69,6 @@ struct command_simple spki_add_userkey_command;
  * ****************/
  
 /* Adds an ACL s-expression to an SPKI-context. Returns the context. */
-/* ;; GABA:
-   (class
-     (name spki_add_acl_command_1)
-     (super command)
-     (vars
-       (ctx object spki_context)))
-*/
 
 static void
 do_spki_add_acl(struct command *s,
@@ -366,7 +359,7 @@ do_spki_encrypt(struct command *s,
 				      sexp_s(NULL, crypt_string_pad
 					     (MAKE_ENCRYPT(self->algorithm,
 							   self->key->data, iv ? iv->data : noiv),
-					      SEXP_FORMAT(expr, SEXP_CANONICAL, 0), 1)),
+					      sexp_format(expr, SEXP_CANONICAL, 0), 1)),
 				      -1),
 			       -1),
 			-1));
