@@ -1,6 +1,6 @@
 /* tcpforward.c
  *
- * $Id: tcpforward.c,v 1.49 2000/06/01 13:18:12 nisse Exp $
+ * $Id: tcpforward.c,v 1.52 2000/06/21 06:40:24 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -149,6 +149,7 @@ do_tcpip_eof(struct ssh_channel *c)
     channel_close(c);
 }
 
+/* NOTE: Adds the socket to the channel's resource list */
 struct ssh_channel *
 make_tcpip_channel(struct lsh_fd *socket, UINT32 initial_window)
 {
@@ -168,6 +169,8 @@ make_tcpip_channel(struct lsh_fd *socket, UINT32 initial_window)
   self->super.rec_max_packet = SSH_MAX_PACKET - SSH_CHANNEL_MAX_PACKET_FUZZ;
   
   self->socket = socket;
+
+  REMEMBER_RESOURCE(self->super.resources, &socket->super);
   
   return &self->super;
 }
@@ -178,7 +181,8 @@ make_tcpip_channel(struct lsh_fd *socket, UINT32 initial_window)
  * (channel_open_continuation has not yet done its work), and we can't
  * send any packets. */
 
-void tcpip_channel_start_io(struct ssh_channel *c)
+void
+tcpip_channel_start_io(struct ssh_channel *c)
 {
   CAST(tcpip_channel, channel, c);
 
